@@ -60,44 +60,46 @@ class ToscaDefTest(TestCase):
 
     def test_group(self):
         self.assertEqual(group_type.type, "tosca.groups.Root")
+        self.assertIsNone(group_type.parent_type)
         self.assertIn(ifaces.LIFECYCLE_SHORTNAME, group_type.interfaces)
 
     def test_capabilities(self):
+        # Assure the normative Compute node type
+        # has all the required Capability types
+        # regardless of symbloc name
+        # TODO(Matt) - since Compute IS a normative node type
+        # we SHOULD test symbolic capability names as well
         self.assertEqual(
             ['tosca.capabilities.Container',
+             'tosca.capabilities.Endpoint.Admin',
              'tosca.capabilities.Node',
              'tosca.capabilities.OperatingSystem',
              'tosca.capabilities.Scalable',
              'tosca.capabilities.network.Bindable'],
             sorted([c.type for c in compute_type.get_capabilities_objects()]))
+        # Assure the normative Network node type
+        # hsa all the required Capability types
+        # TODO(Matt) - since Network IS a normative node type
+        # we SHOULD test symbolic capability names as well
         self.assertEqual(
             ['tosca.capabilities.Node',
              'tosca.capabilities.network.Linkable'],
             sorted([c.type for c in network_type.get_capabilities_objects()]))
-        endpoint_properties = ['initiator', 'network_name', 'port',
-                               'port_name', 'ports', 'protocol',
-                               'secure', 'url_path']
+
+        # Assure the normative WebServer node type's
+        # Endpoint cap. has all required property names
+        # Note: we are testing them in alphabetic sort order
         endpoint_props_def_objects = \
             self._get_capability_properties_def_objects(
                 webserver_type.get_capabilities_objects(),
                 'tosca.capabilities.Endpoint')
+        # Assure WebServer's Endpoint capability's properties have their
+        # required keyname value set correctly
         self.assertEqual(
-            endpoint_properties,
-            sorted([p.name for p in endpoint_props_def_objects]))
-        for p in endpoint_props_def_objects:
-            if p.name in endpoint_properties:
-                self.assertFalse(p.required)
-        endpoint_props_def = self._get_capability_properties_def(
-            webserver_type.get_capabilities_objects(),
-            'tosca.capabilities.Endpoint')
-        self.assertEqual(
-            endpoint_properties,
-            sorted(endpoint_props_def.keys()))
-        endpoint_prop_def = self._get_capability_property_def(
-            webserver_type.get_capabilities_objects(),
-            'tosca.capabilities.Endpoint',
-            'initiator')
-        self.assertEqual(None, endpoint_prop_def)
+            [('initiator', False), ('network_name', False), ('port', False),
+             ('port_name', False), ('ports', False), ('protocol', True),
+             ('secure', False), ('url_path', False)],
+            sorted([(p.name, p.required) for p in endpoint_props_def_objects]))
 
         os_props = self._get_capability_properties_def_objects(
             compute_type.get_capabilities_objects(),
@@ -139,14 +141,6 @@ class ToscaDefTest(TestCase):
                 break
         return properties_def
 
-    def _get_capability_property_def(self, caps, type, property):
-        property_def = None
-        for cap in caps:
-            if cap.type == type:
-                property_def = cap.get_property_def_value(property)
-                break
-        return property_def
-
     def test_properties_def(self):
         self.assertEqual(
             ['name', 'password', 'port', 'user'],
@@ -191,13 +185,14 @@ class ToscaDefTest(TestCase):
              relation, node in network_port_type.relationship.items()])
 
     def test_interfaces(self):
-        self.assertEqual(compute_type.interfaces, None)
+        self.assertIsNone(compute_type.interfaces)
         root_node = NodeType('tosca.nodes.Root')
         self.assertIn(ifaces.LIFECYCLE_SHORTNAME, root_node.interfaces)
 
     def test_artifacts(self):
+        self.assertIsNone(artif_root_type.parent_type)
         self.assertEqual('tosca.artifacts.Root',
-                         artif_file_type.parent_type)
+                         artif_file_type.parent_type.type)
         self.assertEqual({}, artif_file_type.parent_artifacts)
         self.assertEqual(sorted(['tosca.artifacts.Root'],
                                 key=lambda x: str(x)),
@@ -206,7 +201,7 @@ class ToscaDefTest(TestCase):
                                 key=lambda x: str(x)))
 
         self.assertEqual('tosca.artifacts.Implementation',
-                         artif_bash_type.parent_type)
+                         artif_bash_type.parent_type.type)
         self.assertEqual({'tosca.artifacts.Implementation':
                           {'derived_from': 'tosca.artifacts.Root',
                            'description':
@@ -220,7 +215,7 @@ class ToscaDefTest(TestCase):
                                 key=lambda x: str(x)))
 
         self.assertEqual('tosca.artifacts.Implementation',
-                         artif_python_type.parent_type)
+                         artif_python_type.parent_type.type)
         self.assertEqual({'tosca.artifacts.Implementation':
                           {'derived_from': 'tosca.artifacts.Root',
                            'description':
@@ -235,7 +230,7 @@ class ToscaDefTest(TestCase):
                                 key=lambda x: str(x)))
 
         self.assertEqual('tosca.artifacts.Deployment.Image',
-                         artif_container_docker_type.parent_type)
+                         artif_container_docker_type.parent_type.type)
         self.assertEqual({'tosca.artifacts.Deployment':
                           {'derived_from': 'tosca.artifacts.Root',
                            'description':
@@ -252,7 +247,7 @@ class ToscaDefTest(TestCase):
                                 key=lambda x: str(x)))
 
         self.assertEqual('tosca.artifacts.Deployment.Image',
-                         artif_vm_iso_type.parent_type)
+                         artif_vm_iso_type.parent_type.type)
         self.assertEqual({'tosca.artifacts.Deployment':
                           {'derived_from': 'tosca.artifacts.Root',
                            'description':
@@ -271,7 +266,7 @@ class ToscaDefTest(TestCase):
                                 key=lambda x: str(x)))
 
         self.assertEqual('tosca.artifacts.Deployment.Image',
-                         artif_vm_qcow2_type.parent_type)
+                         artif_vm_qcow2_type.parent_type.type)
         self.assertEqual({'tosca.artifacts.Deployment':
                           {'derived_from': 'tosca.artifacts.Root',
                            'description':
@@ -290,8 +285,9 @@ class ToscaDefTest(TestCase):
                                 key=lambda x: str(x)))
 
     def test_policies(self):
+        self.assertIsNone(policy_root_type.parent_type)
         self.assertEqual('tosca.policies.Root',
-                         policy_placement_type.parent_type)
+                         policy_placement_type.parent_type.type)
         self.assertEqual({}, policy_placement_type.parent_policies)
         self.assertEqual(sorted(['tosca.policies.Root',
                                  'The TOSCA Policy Type definition that is '
@@ -303,7 +299,7 @@ class ToscaDefTest(TestCase):
                                 key=lambda x: str(x)))
 
         self.assertEqual('tosca.policies.Root',
-                         policy_scaling_type.parent_type)
+                         policy_scaling_type.parent_type.type)
         self.assertEqual({}, policy_scaling_type.parent_policies)
         self.assertEqual(sorted(['tosca.policies.Root',
                                  'The TOSCA Policy Type definition that is '
@@ -315,7 +311,7 @@ class ToscaDefTest(TestCase):
                                 key=lambda x: str(x)))
 
         self.assertEqual('tosca.policies.Root',
-                         policy_update_type.parent_type)
+                         policy_update_type.parent_type.type)
         self.assertEqual({}, policy_update_type.parent_policies)
         self.assertEqual(sorted(['tosca.policies.Root',
                                  'The TOSCA Policy Type definition that is '
@@ -327,7 +323,7 @@ class ToscaDefTest(TestCase):
                                 key=lambda x: str(x)))
 
         self.assertEqual('tosca.policies.Root',
-                         policy_performance_type.parent_type)
+                         policy_performance_type.parent_type.type)
         self.assertEqual({}, policy_performance_type.parent_policies)
         self.assertEqual(sorted(['tosca.policies.Root',
                                  'The TOSCA Policy Type definition that is '
